@@ -39,8 +39,8 @@
 
 void output(const char* descr, iaddr from, iaddr to, uint8_t proto, unsigned flags,
     unsigned sport, unsigned dport, my_bpftimeval ts,
-    const u_char* pkt_copy, const unsigned olen,
-    const u_char* payload, const unsigned payloadlen);
+    u_char* pkt_copy, const unsigned olen,
+    u_char* payload, const unsigned payloadlen);
 
 int dumper_open(my_bpftimeval ts);
 int dumper_close(my_bpftimeval ts);
